/**
 *
 */
package de.intevation.gnv.transition.profile.vertical;

import java.util.Collection;
import java.util.Locale;

import org.apache.log4j.Logger;

import org.jfree.chart.ChartTheme;

import de.intevation.gnv.chart.Chart;
import de.intevation.gnv.chart.ChartLabels;
import de.intevation.gnv.chart.VerticalProfileChart;
import de.intevation.gnv.statistics.Statistics;
import de.intevation.gnv.statistics.VerticalProfileStatistics;
import de.intevation.gnv.transition.timeseries.TimeSeriesOutputTransition;

/**
 * @author Tim Englich <tim.englich@intevation.de>
 * 
 */
public class VerticalProfileOutputTransition extends TimeSeriesOutputTransition {
    /**
     * The UID of this class
     */
    private static final long serialVersionUID = 4401516087492028840L;

    private static Logger log = Logger
            .getLogger(TimeSeriesOutputTransition.class);

    /**
     * Constructor
     */
    public VerticalProfileOutputTransition() {
        super();
        super.domainLable = "Depth [m]";
    }

    

    @Override
    protected Chart getChart(ChartLabels chartLables, Collection parameters,
                             Collection measurements, Collection result,
                             Collection dates, Locale locale, String uuid) {
        Chart chart = null;

        if (CACHE_CHART) {
            log.info("Try to get verticalprofile chart from cache.");
            chart = (Chart) getChartFromCache(uuid);
        }

        if (chart != null)
            return chart;

        log.info("Chart not in cache yet.");
        chart = new VerticalProfileChart(
            chartLables,
            this.createStyle(),
            parameters,
            measurements,
            result,
            dates,
            locale
        );
        chart.generateChart();

        if (CACHE_CHART) {
            log.info("Put chart into cache.");
            purifyChart(chart, uuid);
        }

        return chart;
    }



    /**
     * @see de.intevation.gnv.transition.timeseries.TimeSeriesOutputTransition#getStatisticsGenerator()
     */
    @Override
    protected Statistics getStatisticsGenerator() {
        return new VerticalProfileStatistics();
    }

}
